<?PHP

// ---------------------------------------------------------------
//
// -----------------------------------------------------
// copyright 2000 by voxeo corporation. (see LGPL.txt)
// -----------------------------------------------------
//
// v1.0 Coded in PHP
// v1.0 Coded by Shane Smith and Stephen J. Lewis
//
// This application allows you to assign up to 10 callxml applications to
// one voxeo phone number.  It is also coded in ASP, Perl, and Coldfusion.   
//
// This zip file contains the following files:				 
//     applicationswitcher.php     <---- This file
//     applicationswitcher.pl      <---- Perl version
//     applicationswitcher.asp     <---- ASP version
//     applicationswitcher.cfm     <---- ColdFusion version
//
//     applicationswitcher.ini     <---- configuration file
//
//     applicationswitcher.mdb     <---- Access 2000 Database that stores the
//                                       locations of each application
//     database-win32.inc          <---- Abstracted database routines for PHP
//                                       under Windows32 environments
//     database-linux.inc          <---- Abstracted database routines for PHP
//                                       under linux environments
//
//     LGPL.txt                    <---- opensource license agreement
//     readme.txt                  <---- Introductory file 
//
//----------------------------------------------------------------

//-------------------------------------------------------------------------------------------

function CheckTheDatabase() {
  //-------------------------------------------------------------------
  // These are our abstracted database routines.  If you are running 
  // off of an interbase database, uncomment the next line and comment
  // out the "include('database-win32.inc');" which uses ODBC routines.
  //
  // Note that the database routines are only necessary, ultimately, if
  // the ApplicationSwitcher.ini file explicitly states that a database
  // is being used.
  //-------------------------------------------------------------------

  // include('database-linux.inc'); 

  include('database-win32.inc');

  $TempArray      = Array();
  $TempConnection = OpenDatabase("ApplicationSwitcher");
  $TempSQL        = "select * from Applications order by AppNum";
  $TempDatabase   = ReadDatabase($TempConnection, $TempSQL);
  $Loopy          = 0;
  
  while ( $TempRow = FetchRowFromDatabase( $TempDatabase ) ) {
    $Loopy++;
    $TempArray["Name" . $Loopy] = GetResultFromRow( "NAME", $TempRow, $TempDatabase );
    $TempArray["URL" . $Loopy]  = GetResultFromRow( "URL",  $TempRow, $TempDatabase );
  }  // while statement
  
  CloseDatabase($TempConnection);
  
  return $TempArray;
}  // CheckTheDatabase function

//-------------------------------------------------------------------------------------------

function GetApplications() {
  $TempArray = Array();
  
  $Key       = "applicationswitcher=";
  $KeyLength = strlen($Key);
  $Loopy     = 0;
  
  //------------------------------------------------------------------
  // First we check the contents of ApplicationSwitcher.ini to see
  // if we need to hit the database or go straight from the text file.
  //------------------------------------------------------------------
  
  $FileContents = file ("applicationswitcher.ini");
  
  while (list ($LineNumber, $Line) = each ($FileContents)) {
    //---------------------------------------------------------
	// We trim any whitespace and then look for our commenting
	// characters, which are a double forward slash ("//") at
	// the beginning of the line.  This means ignore that line.
	//---------------------------------------------------------
	
    $Line     = trim(strtolower($Line));
    $Position = strpos($Line, "//");
	
	if (($Position === FALSE) || ($Position > 0)) {
	  //--------------------------------
	  // Make sure the line is not blank
	  //--------------------------------
	  
	  if ($Line != "") {
	    $Position     = strpos($Line, $Key);
		$PipePosition = strpos($Line, "|");
		
		//------------------------------------------------
		// Check both for the applicationswitcher variable
		// in the INI file, and URL mappings.  
		//------------------------------------------------
		
		if (strstr($Line, $Key)) {
		  $DatabaseOrTextFile = substr($Line, $Position + $KeyLength);
        }  // if statement
		elseif (strstr($Line, "|")) {
          list ($TempName, $TempURL) = split ('[|]', $Line);
		  
		  //---------------------------------------
		  // Make sure that is both a menu name and 
		  // a mapped URL, otherwise ignore it.
		  //---------------------------------------
		  
		  if (($TempName != "") && ($TempURL != "")) {
		    $Loopy++;
		    $TempArray["Name" . $Loopy] = $TempName;
		    $TempArray["URL" . $Loopy]  = $TempURL;
		  }  // if statement
		}  // elseif statement
	  }  // if statement
	}  // if statement
  }  // while statement
  
  //------------------------------------------------------------------
  // If the user wants to use the database instead, then load the 
  // information, otherwise default to using the INI file information.
  //------------------------------------------------------------------
  
  if ($DatabaseOrTextFile == "database") { $TempArray = CheckTheDatabase(); }
  
  return $TempArray;
}  // function ParseIniFile

//-------------------------------------------------------------------------------------------

function MainMenu() {
  $TempArray    = Array();
  
  $TempArray    = GetApplications();
  
  $NamesText    = "";
  $URLsText     = "";
  $TermDigits   = "";
  $NumberOfURLs = 0;
  
  //------------------------------------------------------------------------------------
  // First we determine the termdigits -- remember, we only support 10 applications here
  // This is because the <text> element currently clears out the digit buffer.  Thus
  // you can use termdigits, but not a <getdigits> -- otherwise, you have to listen to
  // the entire menu list before choosing.
  //------------------------------------------------------------------------------------
  
  $Loopy = 1;
   
  while (($TempArray["URL" . $Loopy] != "") && ($Loopy < 11)) {
    $NumberOfURLs = $Loopy;

    if ($Loopy == 10) { $TermDigits = $TermDigits . "0";    }
	else              { $TermDigits = $TermDigits . $Loopy; }
	
	$Loopy++;
  }  // while loop
 
  //---------------------------------------------
  // Next we determine the Text-To-Speech message
  // And the event handlers.
  //---------------------------------------------
  
  $Loopy     = 1;
  $NamesText = "<text termdigits=\"" . $TermDigits . "\">,,,,";
  
  for ($Loopy = 1; $Loopy <= $NumberOfURLs; $Loopy++) {
    if ($Loopy == 10) { $Digit = "0";    }
	else              { $Digit = $Loopy; }
	
	$NamesText = $NamesText . "For " . $TempArray["Name" . $Loopy] . ", press " . $Digit . ",,";

	//-----------------------------------------------------------
    // We just dynammically build our <ontermdigit> handler here.
    //-----------------------------------------------------------
	
    $URLsText  = $URLsText . 
	             "<ontermdigit value=\"" . $Digit . "\">" .
	             "  <goto value=\"" . $TempArray["URL" . $Loopy] . "\" cache=\"no\"/>" .
				 "</ontermdigit>";
  }  // for loopy
  
  $NamesText = $NamesText . "</text>";
  
  if ($NumberOfURLs == 0) {
    $NamesText = "<text>I'm sorry, there are currently no applications to choose from.</text>";
  }  // if statement
  
  //----------------------------------------------------------
  // Here is where we actually display the entire menu, having 
  // been created from the database.
  //----------------------------------------------------------
  
  echo "<block label=\"MainMenu\" " . 
		       "repeat=\"3\">";
					
  echo $NamesText;

  echo $URLsText;		
  
  echo "</block>";
}  // MainMenu function

//-------------------------------------------------------------------------------------------

function Initialize() {
  echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"; 
  echo "<callxml>";
}  // Initialize function

//-------------------------------------------------------------------------------------------

function Closure() {
  echo "</callxml>";
}  // Closure function

//------------------------------------------------------------------------------------------- 

Initialize();
Mainmenu();
Closure();

?>